pub struct NumPyReference {
pub range: TextRange,
pub directive_marker: Option<TextRange>,
pub open_bracket: Option<TextRange>,
pub number: TextRange,
pub close_bracket: Option<TextRange>,
pub content: TextRange,
}Expand description
Numbered reference (from References section).
Represents an RST citation reference like .. [1] Author, Title.
Fields
range: TextRangeSource span.
directive_marker: Option<TextRange>The RST directive marker (..) with its span, if present.
None for non-RST (plain text) references.
open_bracket: Option<TextRange>Opening bracket ([) enclosing the reference number, with its span, if present.
number: TextRangeReference number (e.g., “1”, “2”, “3”) with its span.
close_bracket: Option<TextRange>Closing bracket (]) enclosing the reference number, with its span, if present.
content: TextRangeReference content (author, title, etc) with its span.